@@ -114,7 +114,7 @@
 ##'   savings time (DST) applied or not. Examples include
 ##'   \code{local.tz = "Europe/London"}, \code{local.tz =
 ##'   "America/New_York"} i.e. time zones that assume DST.
-##'   \url{http://en.wikipedia.org/wiki/List_of_zoneinfo_time_zones}
+##'   \url{https://en.wikipedia.org/wiki/List_of_zoneinfo_time_zones}
 ##'   shows time zones that should be valid for most systems. It is
 ##'   important that the original data are in GMT (UTC) or a fixed
 ##'   offset from GMT. See \code{import} and the openair manual for
@@ -165,7 +165,7 @@ cutData <- function(x, type = "default", hemisphere = "northern",
     # }
 
     conds <- c(
-      "default", "year", "hour", "month", "season",
+      "default", "year", "hour", "month", "season", "week",
       "weekday", "wd", "site", "weekend", "monthyear",
       "bstgmt", "gmtbst", "dst", "daylight", "seasonyear",
       "yearseason"
@@ -272,6 +272,11 @@ cutData <- function(x, type = "default", hemisphere = "northern",
       x[[type]] <- format(x$date, "%B %Y")
       x[[type]] <- ordered(x[[type]], levels = unique(x[[type]]))
     }
+    
+    if (type == "week") {
+      x[[type]] <- format(x$date, "%W")
+      x[[type]] <- ordered(x[[type]], levels = unique(x[[type]]))
+    }
 
     if (type == "season") {
       if (!hemisphere %in% c("northern", "southern")) {
